pub async fn export_secrets_bundle_from_store(
database_path: impl AsRef<Path>,
passphrase: Option<&str>,
) -> Result<Option<(OwnedUserId, SecretsBundle)>, BundleExportError>Available on crate features
e2e-encryption and sqlite only.Expand description
Attempt to export a SecretsBundle from a crypto store.
This method can be used to retrieve a SecretsBundle from an existing
matrix-sdk-based client in order to import the SecretsBundle in
another Client instance.
This can be useful for migration purposes or to allow existing client instances create new ones that will be fully verified.